clear all
close all
home

%An example MATLAB code for the dataset, Groon_2015, that plots the mean
%absorbance, mean Zmag, and mean Zang for the data. There is only one session per subject, so this
%code shows a simple way to plot without having to take into account
%multiple sessions.

%%Made with MATLAB R2019a

%load in tables from database via mySQL
data = readtable('wai_measurements.csv');
Subjects_Table = readtable('wai_subjects.csv');

%only use PI we are checking 
PI = 'Groon_2015';
data=data(strcmp(data.Identifier, PI),:);
Subjects_Table = Subjects_Table(strcmp(Subjects_Table.Identifier, PI),:);


%get frequencies
Frequency = unique(data.Frequency);
Groon_freqs = Frequency;

%get subject numbers and the number of subjects
SubjectNumbers=unique(data.SubjectNumber);
NumberSubjects=length(SubjectNumbers);

%make sure number of subjects is correct from subjects table, should be 21
NumSubs = length(unique(Subjects_Table.SubjectNumber)); %it's 21, so it's correct


%get mean absorbance ready to plot
Absorbance = [];
%go through all the frequencies and find the mean absorbance for each
%frequency
%Groon only has one measurement per subject, so to get mean absorbance, we
%can average the absorbance over each frequency
%to do it this way, first make sure the data only has one measurement per
%subject
for freq_index=1:length(Groon_freqs)
    %find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    %get the absorbances at each frequency
    Absorbance = [Absorbance; data.Absorbance(freq_rows).'];
    %get the mean absorbance at each frequency
    mean_Abs = nanmean(Absorbance,2);
end


%get mean Zmag (MKS Ohms) ready to plot
ImpedanceMag = [];
%go through all the frequencies and find the mean Zmag for each
%frequency
%Groon only has one measurement per subject, so to get mean Zmag, we
%can average the Zmag over each frequency
%to do it this way, first make sure the data only has one measurement per
%subject
for freq_index=1:length(Groon_freqs)
    %find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    %get the impedance magnitudes at each frequency
    ImpedanceMag = [ImpedanceMag; str2num(char(data.Zmag(freq_rows))).'];
    %get the mean Zmag at each frequency
    mean_Zmag = nanmean(ImpedanceMag,2);
end


%get mean Zang (cycles) ready to plot
ImpedanceAng = [];
%go through all the frequencies and find the mean Zang for each
%frequency
%Groon only has one measurement per subject, so to get mean Zang, we
%can average the Zang over each frequency
%to do it this way, first make sure the data only has one measurement per
%subject
for freq_index=1:length(Groon_freqs)
    %find all the rows for the frequency each loop
    freq_rows = find(data.Frequency==Groon_freqs(freq_index));
    %get the impedance angles at each frequency
    ImpedanceAng = [ImpedanceAng; str2num(char(data.Zang(freq_rows))).'];
    %get the mean absorbance at each frequency
    mean_Zang = nanmean(ImpedanceAng,2);
end


%plot absorbance of each subject, mean absorbance, magnitude of the
%impedance of each subject, mean magnitude of impedance, angle of impedance
%of each subject, mean angle of impedance
figure(1)
sgtitle('Groon et al. (2015)', 'FontSize', 20)
subplot(332)
semilogx(Frequency, Absorbance, 'm', 'LineWidth', 0.5)
hold on
semilogx(Frequency, mean_Abs, 'b', 'LineWidth', 3)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Absorbance')
hold off
subplot(335)
loglog(Frequency, ImpedanceMag, 'm', 'LineWidth', 0.5)
hold on
semilogx(Frequency, mean_Zmag, 'b', 'LineWidth', 3)
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Impedance')
title('Magnitude (MKS Ohms)')
hold off
subplot(338)
semilogx(Frequency, ImpedanceAng, 'm', 'LineWidth', 0.5)
hold on
semilogx(Frequency, mean_Zang, 'b', 'LineWidth', 3)
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Angle (cycles)')
title('Impedance')
hold off

